function testdemoplayerPaxes


%---Demo Version:     1.2
%   Author:           jl, 16-Jul-2006
%   M-File Version:   1.0
%   Revision:
%   Date:
%   Copyright ITUU University of Ulm
%
%
%---------------------------Use of plot axes (paxes) = axes within plotbox
%
%                        -> demo, example:
%                           plot 2 curves, vary y of curve 2
%                           goal: "smooth" plot image
%
%                        -> approach:
%                           a) plot 2 curves with different tags:
%                              'Plotline1', 'Plotline2'
%                           b) for 'Plotline2' set erase mode to 'background'
%                              in a loop vary y values of 'Plotline2'
%                              erase mode = 'background': variation without
%                              drawing the whole image again => flicker-free image
%                              disadvantage: axes grid will be overwritten
%                              therefore uniplayerset('PLOTBOX-REFRESH1') at end
%                           c) 2 text patches, one text fixed, second variable
%                              variable text also with erase mode = 'background'
%                              position: x/y values between 0 and 1
%
%                        -> in uniplayerset statements:
%                           1) key - value pair, example: 'COL',[1 0 0] 
%                              in Matlab: property - value pair for set/get
%                                         property in this example: 'color'
%                                         value same as with key='COL'
%                              => key = abbreviation of Matlab property
%                              also called "Setgui" or "Getgui" key
%                              see Setgui/Getgui - Matlab correspondence below
%                           2) key = Matlab property also allowed
%                              example: 'color',[1 0 0]
%                           3) any number of key - value pairs may be added
%                              example: ...,'FNS',12,'FNW','bold','COL',[0 1 0],...
%
y=[1 2 3 3 4 3];
x=[1:length(y)];

uniplayerset('PLOTBOX-PAXES-CRE')
uniplayerset('PLOTBOX-PAXES-PLO','Plotline1',x,y,'COL',[1 0 0]);
y=[0 1 2 2 3 2];
uniplayerset('PLOTBOX-PAXES-PLO','Plotline2',x,y,'LWI',2,'COL',[0 1 0],'ERM','background');

str='Demo: Test Paxes';
pos=[0.45,0.40];
uniplayerset('PLOTBOX-PAXES-TXT','Text1','STR',str,'POS',pos)
uniplayerset('PLOTBOX-PAXES-TXT','Text1','FNS',12,'FNW','bold','COL',[0 1 1])
uniplayerset('PLOTBOX-PAXES-TXT','Text1','BCO',[0.2 0.2 0.2],'edgecolor',[1 1 1])

str='';
pos=[0.47,0.30];
uniplayerset('PLOTBOX-PAXES-TXT','Text2','STR',str,'POS',pos,'BCO',[0 0 0])
uniplayerset('PLOTBOX-PAXES-TXT','Text2','FNS',12,'FNW','bold','COL',[0 1 0])
uniplayerset('PLOTBOX-PAXES-TXT','Text2','ERM','background')



for i=1:50
   pause(0.01)
   y=y+0.01;
   uniplayerset('PLOTBOX-PAXES-PLO','Plotline2','XDA',x,'YDA',y)%--'XDA' actually not needed
end

for k=1:4
   pm=1;
   if k==2|k==4 pm=-1; end
   for i=1:50
      pause(0.01)
      y(1)=y(1)+pm*0.04;
      y(end)=y(end)-pm*0.04;
      uniplayerset('PLOTBOX-PAXES-PLO','Plotline2','YDA',y)
      str=['k = ',num2str(k),'  i = ',num2str(i)];
      uniplayerset('PLOTBOX-PAXES-TXT','Text2','STR',str)
   end
end

uniplayerset('PLOTBOX-REFRESH1')



return





%----------------------------Setgui/Getgui key --- corresponding Matlab property key
%                            val same as Matlab
%
keystr=[...
      'BCO---BackgroundColor;',...
      'BOX---Box;',...
      'BSY---BusyAction;',...
      'CDA---Cdata;',...
      'CHE---Checked;',...
      'COL---Color;',...
      'DEL---Delete;',...
      'ENA---Enable;',...
      'ERM---EraseMode;',...
      'FCO---ForegroundColor;',...
      'FIL---Filename;',...
      'FNA---Fontname;',...
      'FNS---Fontsize;',...
      'FNW---Fontweight;',...
      'HAL---HorizontalAlignment;',...
      'ITR---Interruptible;',...
      'LAY---Layer;',...
      'LBL---Label;',...
      'LBT---Listboxtop;',...
      'LST---Linestyle;',...
      'LWI---Linewidth;',...
      'MAX---Max;',...
      'MIN---Min;',...
      'NAM---Name;',...
      'NPL---NextPlot;',...
      'PAR---Parent;',...
      'POR---PaperOrientation;',...
      'POS---Position;',...
      'PTR---Pointer;',...
      'SEL---Selected;',...
      'SEP---Separator;',...
      'SST---Sliderstep;',...
      'STR---String;',...
      'STY---Style;',...
      'TIP---TooltipString;',...
      'TAG---Tag;',...
      'USD---Userdata;',...
      'UNI---Units;',...
      'VAL---Value;',...
      'VIS---Visible;',...
      'XCO---Xcolor;',...
      'XDA---Xdata;',...
      'XLI---Xlim;',...
      'YCO---Ycolor;',...
      'YDA---Ydata;',...
      'YDI---Ydir;',...
      'YLI---Ylim;'];




